import { PluginsManager } from '@/services/pluginsManager';
import axios from 'axios';
import { ChangeEvent, useState } from 'react';

type UseLoadPluginReturnType = {
  handleChangePluginUrl: (event: ChangeEvent<HTMLInputElement>) => void;
  handleLoadPlugin: () => Promise<void>;
  isPending: boolean;
  pluginUrl: string;
};

export const useLoadPluginFromUrl = (): UseLoadPluginReturnType => {
  const [pluginUrl, setPluginUrl] = useState('');

  const isPending = !pluginUrl;

  const handleLoadPlugin = async (): Promise<void> => {
    const response = await axios(pluginUrl);
    const pluginScript = response.data;

    /* eslint-disable no-new-func */
    const loadPlugin = new Function(pluginScript);

    PluginsManager.setHashedPlugin({
      pluginUrl,
      pluginScript,
    });

    loadPlugin();
    setPluginUrl('');
  };
  const handleChangePluginUrl = (event: ChangeEvent<HTMLInputElement>): void => {
    setPluginUrl(event.target.value);
  };

  return {
    handleChangePluginUrl,
    handleLoadPlugin,
    isPending,
    pluginUrl,
  };
};
